@@ -13,9 +13,6 @@
 // limitations under the License.
 
 // Utility for international phone numbers.
-//
-// Author: Shaopeng Jia
-// Open-sourced by: Philippe Liard
 
 #ifndef I18N_PHONENUMBERS_PHONENUMBERUTIL_H_
 #define I18N_PHONENUMBERS_PHONENUMBERUTIL_H_
@@ -38,14 +35,8 @@ class TelephoneNumber;
 namespace i18n {
 namespace phonenumbers {
 
-using std::list;
-using std::map;
-using std::pair;
-using std::set;
-using std::string;
-using std::vector;
-
 using google::protobuf::RepeatedPtrField;
+using std::string;
 
 class AsYouTypeFormatter;
 class Logger;
@@ -180,6 +171,12 @@ class PhoneNumberUtil : public Singleton<PhoneNumberUtil> {
   void GetSupportedGlobalNetworkCallingCodes(
       std::set<int>* calling_codes) const;
 
+  // Returns all country calling codes the library has metadata for, covering
+  // both non-geographical entities (global network calling codes) and those
+  // used for geographical entities. This could be used to populate a drop-down
+  // box of country calling codes for a phone-number widget, for instance.
+  void GetSupportedCallingCodes(std::set<int>* calling_codes) const;
+
   // Returns the types for a given region which the library has metadata for.
   // Will not include FIXED_LINE_OR_MOBILE (if numbers for this non-geographical
   // entity could be classified as FIXED_LINE_OR_MOBILE, both FIXED_LINE and
@@ -387,8 +384,11 @@ class PhoneNumberUtil : public Singleton<PhoneNumberUtil> {
   // number is parsed from. The original format is embedded in the
   // country_code_source field of the PhoneNumber object passed in. If such
   // information is missing, the number will be formatted into the NATIONAL
-  // format by default. When the number is an invalid number, the method returns
-  // the raw input when it is available.
+  // format by default. When we don't have a formatting pattern for the number,
+  // the method returns the raw input when it is available.
+  //
+  // Note this method guarantees no digit will be inserted, removed or modified
+  // as a result of formatting.
   void FormatInOriginalFormat(const PhoneNumber& number,
                               const string& region_calling_from,
                               string* formatted_number) const;
@@ -422,7 +422,7 @@ class PhoneNumberUtil : public Singleton<PhoneNumberUtil> {
   // be successfully extracted.
   bool TruncateTooLongNumber(PhoneNumber* number) const;
 
-  // Gets the type of a phone number.
+  // Gets the type of a valid phone number, or UNKNOWN if it is invalid.
   PhoneNumberType GetNumberType(const PhoneNumber& number) const;
 
   // Tests whether a phone number matches a valid pattern. Note this doesn't
@@ -478,7 +478,7 @@ class PhoneNumberUtil : public Singleton<PhoneNumberUtil> {
   // is left unchanged.
   void GetRegionCodesForCountryCallingCode(
       int country_calling_code,
-      list<string>* region_codes) const;
+      std::list<string>* region_codes) const;
 
   // Checks if this is a region under the North American Numbering Plan
   // Administration (NANPA).
@@ -588,14 +588,11 @@ class PhoneNumberUtil : public Singleton<PhoneNumberUtil> {
   bool CanBeInternationallyDialled(const PhoneNumber& number) const;
 
   // Tests whether a phone number has a geographical association. It checks if
-  // the number is associated to a certain region in the country where it
-  // belongs to. Note that this doesn't verify if the number is actually in use.
+  // the number is associated with a certain region in the country to which it
+  // belongs. Note that this doesn't verify if the number is actually in use.
   bool IsNumberGeographical(const PhoneNumber& phone_number) const;
 
-  // Tests whether a phone number has a geographical association, as represented
-  // by its type and the country it belongs to.
-  //
-  // This version of IsNumberGeographical exists since calculating the phone
+  // Overload of IsNumberGeographical(PhoneNumber), since calculating the phone
   // number type is expensive; if we have already done this, we don't want to do
   // it again.
   bool IsNumberGeographical(PhoneNumberType phone_number_type,
@@ -658,7 +655,15 @@ class PhoneNumberUtil : public Singleton<PhoneNumberUtil> {
   // a particular region is not performed. This can be done separately with
   // IsValidNumber().
   //
-  // number_to_parse can also be provided in RFC3966 format.
+  // Note this method canonicalizes the phone number such that different
+  // representations can be easily compared, no matter what form it was
+  // originally entered in (e.g. national, international). If you want to record
+  // context about the number being parsed, such as the raw input that was
+  // entered, how the country code was derived etc. then call
+  // ParseAndKeepRawInput() instead.
+  //
+  // number_to_parse can contain formatting such as +, ( and -, as well as a
+  // phone number extension. It can also be provided in RFC3966 format.
   //
   // default_region represents the country that we are expecting the number to
   // be from. This is only used if the number being parsed is not written in
@@ -732,11 +737,6 @@ class PhoneNumberUtil : public Singleton<PhoneNumberUtil> {
                                             TelephoneNumber* resulting_proto);
 
  protected:
-  // Check whether the country_calling_code is from a country whose national
-  // significant number could contain a leading zero. An example of such a
-  // country is Italy.
-  bool IsLeadingZeroPossible(int country_calling_code) const;
-
   bool IsNumberMatchingDesc(const string& national_number,
                             const PhoneNumberDesc& number_desc) const;
 
@@ -746,7 +746,7 @@ class PhoneNumberUtil : public Singleton<PhoneNumberUtil> {
  private:
   scoped_ptr<Logger> logger_;
 
-  typedef pair<int, list<string>*> IntRegionsPair;
+  typedef std::pair<int, std::list<string>*> IntRegionsPair;
 
   // The minimum and maximum length of the national significant number.
   static const size_t kMinLengthForNsn = 2;
@@ -787,20 +787,21 @@ class PhoneNumberUtil : public Singleton<PhoneNumberUtil> {
   // country calling code 7. Under this map, 1 is mapped to region code "US" and
   // 7 is mapped to region code "RU". This is implemented as a sorted vector to
   // achieve better performance.
-  scoped_ptr<vector<IntRegionsPair> > country_calling_code_to_region_code_map_;
+  scoped_ptr<std::vector<IntRegionsPair> >
+      country_calling_code_to_region_code_map_;
 
   // The set of regions that share country calling code 1.
-  scoped_ptr<set<string> > nanpa_regions_;
+  scoped_ptr<std::set<string> > nanpa_regions_;
   static const int kNanpaCountryCode = 1;
 
   // A mapping from a region code to a PhoneMetadata for that region.
-  scoped_ptr<map<string, PhoneMetadata> > region_to_metadata_map_;
+  scoped_ptr<std::map<string, PhoneMetadata> > region_to_metadata_map_;
 
   // A mapping from a country calling code for a non-geographical entity to the
   // PhoneMetadata for that country calling code. Examples of the country
   // calling codes include 800 (International Toll Free Service) and 808
   // (International Shared Cost Service).
-  scoped_ptr<map<int, PhoneMetadata> >
+  scoped_ptr<std::map<int, PhoneMetadata> >
       country_code_to_non_geographical_metadata_map_;
 
   PhoneNumberUtil();
@@ -875,11 +876,6 @@ class PhoneNumberUtil : public Singleton<PhoneNumberUtil> {
       const string& national_prefix,
       const string& region_code) const;
 
-  // Returns true if a number is from a region whose national significant number
-  // couldn't contain a leading zero, but has the italian_leading_zero field set
-  // to true.
-  bool HasUnexpectedItalianLeadingZero(const PhoneNumber& number) const;
-
   bool HasFormattingPatternForNumber(const PhoneNumber& number) const;
 
   // Simple wrapper of FormatNsnWithCarrier for the common case of
@@ -903,7 +899,7 @@ class PhoneNumberUtil : public Singleton<PhoneNumberUtil> {
 
   void GetRegionCodeForNumberFromRegionList(
       const PhoneNumber& number,
-      const list<string>& region_codes,
+      const std::list<string>& region_codes,
       string* region_code) const;
 
   // Strips the IDD from the start of the number if present. Helper function
